@@ -619,7 +619,7 @@ sub semantic_labels {
   if (my @lowres = map {[split ':']}
       grep {/^$label:(\d+)/ && $1 <= $length}
       $self->configured_types) {
-	return $label,map {join ':',@$_} sort {$a->[1] <=> $b->[1]} @lowres;
+	return $label,map {join ':',@$_} sort {$a->[-1] <=> $b->[-1]} @lowres;
   }
   return $label
 }
@@ -636,7 +636,7 @@ sub semantic_label {
       grep {/^$label:(\d+)/ && $1 <= $length}
       $self->configured_types)
     {
-      ($label) = map {join ':',@$_} sort {$b->[1] <=> $a->[1]} @lowres;
+      ($label) = map {join ':',@$_} sort {$b->[-1] <=> $a->[-1]} @lowres;
     }
   $label
 }
@@ -1033,7 +1033,6 @@ sub default_dbid {
     return $self->db2id($self->open_database);
 }
 
-
 sub search_options {
     my $self = shift;
     my $dbid = shift;
