@@ -271,7 +271,6 @@ sub make_requests {
     foreach my $label ( @{ $labels || [] } ) {
 
         my @track_args = $self->create_track_args( $label, $args );
-
 	my (@filter_args,@featurefile_args,@subtrack_args);
 
 	my $format_option = $settings->{features}{$label}{options};
@@ -424,6 +423,8 @@ sub wrap_rendered_track {
     my $kill     = "$buttons/ex.png";
     my $share    = "$buttons/share.png";
     my $help     = "$buttons/query.png";
+    my $pop_in   = "$buttons/pop_in.png";
+    my $pop_out  = "$buttons/pop_out.png";
     my $download = "$buttons/download.png";
     my $configure= "$buttons/tools.png";
     my $menu 	 = "$buttons/menu.png";
@@ -453,6 +454,7 @@ sub wrap_rendered_track {
             -height => $height,
             -border => 0,
             -name   => $label,
+	    -class  => 'track_image',
             -style  => $img_style
 	    
         }
@@ -478,6 +480,10 @@ sub wrap_rendered_track {
     $about_this_track .= $self->language->translate('ABOUT_THIS_TRACK',$label)
         || "<b>About this track</b>";
 
+    my $popout = '';
+    $popout .= $self->language->translate('POP_OUT') 
+	|| "<b>Pop out/in</b>";
+
     my $escaped_label = CGI::escape($label);
 
     # The inline config will go into a box 500px wide by 500px tall
@@ -504,8 +510,6 @@ sub wrap_rendered_track {
     my $help_url       = "url:?action=cite_track;track=$escaped_label";
     my $help_click     = "GBox.showTooltip(event,'$help_url',1)"; 
 
-    
-
     my $download_click = "GBox.showTooltip(event,'url:?action=download_track_menu;track=$escaped_label;view_start='+TrackPan.get_start()+';view_stop='+TrackPan.get_stop(),true)" unless $label =~ /^(http|ftp)/;
 
     my $title;
@@ -578,16 +582,22 @@ sub wrap_rendered_track {
 				$self->if_not_ipad(-onMouseOver => "$balloon_style.showTooltip(event,'$configure_this_track')"),
 			    })
 	              : '',
+	);
 
-        img({   -src         => $help,
-                 -style       => 'cursor:pointer',
-                 -onmousedown => $help_click,
-                 -onMouseOver =>
-             "$balloon_style.showTooltip(event,'$about_this_track')",
-             }
-        )
-	); 
-
+    my $help_img = img({   -src         => $help,
+			   -style       => 'cursor:pointer',
+			   -onmousedown => $help_click,
+			   -onMouseOver =>
+			       "$balloon_style.showTooltip(event,'$about_this_track')",
+		       });
+    
+    my $pin_img = img({ -src          => $pop_out,
+			-class        => 'pin_button',
+			-onmousedown  => 'Controller.ghost_track(this)',
+			-onmouseover  => "$balloon_style.showTooltip(event,'$popout')",
+		      }
+	);
+	    
     my $ipad_collapse = $collapsed ? 'Expand':'Collapse';
     my $cancel_ipad = 'Turn off';
     my $share_ipad = 'Share'; 
@@ -599,36 +609,38 @@ sub wrap_rendered_track {
     my $menuicon = img ({-src => $menu, 
 			 -style => 'padding-right:15px;',},),
    
-    my $popmenu = div({-id =>"popmenu_${title}", -style => 'display:none'},
-		      div({-class => 'ipadtitle', -id => "${label}_title",}, $title ),
-		      div({-class => 'ipadcollapsed', 
-			   -id    => "${label}_icon", 
-			   -onClick =>  "collapse('$label')",
-			  },
-			  div({-class => 'linkbg', 
-			       -onClick => "swap(this,'Collapse','Expand')", 
-			       -id => "${label}_expandcollapse", },$ipad_collapse)),
-		      div({-class => 'ipadcollapsed',
-			   -id => "${label}_kill",
-			   -onClick     => "ShowHideTrack('$label',false)",
-			  }, div({-class => 'linkbg',},
-				 $cancel_ipad)),
-		      div({-class => 'ipadcollapsed',  
-			   -onMousedown => "Controller.get_sharing(event,'url:?action=share_track;track=$escaped_label',true)",}, 
-			  div({-class => 'linkbg',},$share_ipad)),
-		      div({-class => 'ipadcollapsed',  -
-			       onmousedown => $config_click,}, div({-class => 'linkbg',},$configure_ipad)),
-		      div({-class => 'ipadcollapsed',  
-			   -onmousedown => $fav_click,}, 
-			  div({-class => 'linkbg', -onClick => "swap(this,'Favorite','Unfavorite')"},$bookmark)),
-		      div({-class => 'ipadcollapsed',  
-			   -onmousedown => $download_click,}, 
-			  div({-class => 'linkbg',},$download_ipad)),
-		      div({-class => 'ipadcollapsed', 
-			   -style => 'width:200px',  
-			   -onmousedown => $help_click,}, 
-			  div({-class => 'linkbg', -style => 'position:relative; left:30px;',},$about_ipad)),
- 		  );
+    my $popmenu = $self->if_ipad(
+	div({-id =>"popmenu_${title}", -style => 'display:none'},
+	    div({-class => 'ipadtitle', -id => "${label}_title",}, $title ),
+	    div({-class => 'ipadcollapsed', 
+		 -id    => "${label}_icon", 
+		 -onClick =>  "collapse('$label')",
+		},
+		div({-class => 'linkbg', 
+		     -onClick => "swap(this,'Collapse','Expand')", 
+		     -id => "${label}_expandcollapse", },$ipad_collapse)),
+	    div({-class => 'ipadcollapsed',
+		 -id => "${label}_kill",
+		 -onClick     => "ShowHideTrack('$label',false)",
+		}, div({-class => 'linkbg',},
+		       $cancel_ipad)),
+	    div({-class => 'ipadcollapsed',  
+		 -onMousedown => "Controller.get_sharing(event,'url:?action=share_track;track=$escaped_label',true)",}, 
+		div({-class => 'linkbg',},$share_ipad)),
+	    div({-class => 'ipadcollapsed',  -
+		     onmousedown => $config_click,}, div({-class => 'linkbg',},$configure_ipad)),
+	    div({-class => 'ipadcollapsed',  
+		 -onmousedown => $fav_click,}, 
+		div({-class => 'linkbg', -onClick => "swap(this,'Favorite','Unfavorite')"},$bookmark)),
+	    div({-class => 'ipadcollapsed',  
+		 -onmousedown => $download_click,}, 
+		div({-class => 'linkbg',},$download_ipad)),
+	    div({-class => 'ipadcollapsed', 
+		 -style => 'width:200px',  
+		 -onmousedown => $help_click,}, 
+		div({-class => 'linkbg', -style => 'position:relative; left:30px;',},$about_ipad)),
+	));
+    $popmenu ||= ''; # avoid uninit variable warning
     
     my $clipped_title = $title;
     $clipped_title    = substr($clipped_title,0,MAX_TITLE_LEN-3).'...' if length($clipped_title) > MAX_TITLE_LEN;
@@ -641,13 +653,12 @@ sub wrap_rendered_track {
 		{   -class => $collapsed ? 'titlebar_inactive' : 'titlebar',
 		    -id => "${label}_title",
 				},
-
- 	    $self->if_not_ipad(@images,),
-	    $self->if_ipad(span({-class => 'menuclick',  -onClick=> "GBox.showTooltip(event,'load:popmenu_${title}')"}, $menuicon,),),	
-	    span({-class => 'drag_region',},$clipped_title),
-
+ 	    $self->if_not_ipad(@images),
+	    $self->if_ipad(span({-class => 'menuclick',  -onClick=> "GBox.showTooltip(event,'load:popmenu_${title}')"}, $menuicon,)),
+	    span({-class => 'drag_region'},
+		 span({-style=>'display:inline-block;width:32px'},'&nbsp;'),
+		 $clipped_title.'&nbsp;'.$help_img.span({-style=>'display:inline-block;width:32px'},'&nbsp;').$pin_img)
 	);
-
     my $show_titlebar
         = ( ( $source->setting( $label => 'key' ) || '' ) ne 'none' );
     my $is_scalebar = $label =~ /scale/i;
@@ -668,6 +679,7 @@ sub wrap_rendered_track {
             -width  => $pad->width,
             -border => 0,
             -id     => "${label}_pad",
+	    -class  => 'track_image',
             -style  => $collapsed ? "display:inline" : "display:none",
         }
     );
@@ -698,7 +710,7 @@ sub wrap_rendered_track {
 			      -style => "position:absolute; top:0px; width:100%; left:0px", }, $pan_left . $pan_right . $scale_div);
     }
 
-    my $inner_div = div( { -id => "${label}_inner_div" }, $img . $pad_img ); #Should probably improve this
+    my $inner_div = div( { -id => "${label}_inner_div",-class=>'inner_div' }, $img . $pad_img ); #Should probably improve this
 
 
     my $subtrack_labels = join '',map {
@@ -791,13 +803,11 @@ sub run_remote_requests {
   }
 
   # sort requests by their renderers
-  my $slave_status = Bio::Graphics::Browser2::Render::Slave::Status->new(
-      $source->globals->slave_status_path
-      );
+  my $slave_status = $self->slave_status;
 
   my %renderers;
   for my $label (@labels_to_generate) {
-      my $url     = $source->remote_renderer or next;
+      my $url     = $source->remote_renderer($label) or next;
       my @urls    = shellwords($url);
       $url        = $slave_status->select(@urls);
       warn "label => $url (selected)" if DEBUG;
@@ -819,13 +829,14 @@ sub run_remote_requests {
 
   for my $url (keys %renderers) {
 
-      my $child   = $render->fork();
+      my $child   = Bio::Graphics::Browser2::Render->fork();
       next if $child;
 
       my $total_time = time();
 
       # THIS PART IS IN THE CHILD
       my @labels   = keys %{$renderers{$url}};
+      warn "REMOTE FETCH ON @labels" if DEBUG;
       my $s_track  = Storable::nfreeze(\@labels);
 
       foreach (@labels) {
@@ -885,7 +896,7 @@ sub run_remote_requests {
 			    } @labels;
 	    my $alternate_url = $slave_status->select(keys %urls);
 	    if ($alternate_url) {
-		warn "retrying fetch of @labels with $alternate_url";
+		warn "[$$] retrying fetch of @labels with $alternate_url";
 		$url = $alternate_url;
 		redo FETCH if $tries++ < SLAVE_RETRIES;
 	    }
@@ -902,6 +913,15 @@ sub run_remote_requests {
   }
 }
 
+sub slave_status {
+    my $self = shift;
+    my $source = $self->source;
+    return $self->{slave_status} ||=
+	Bio::Graphics::Browser2::Render::Slave::Status->new(
+	    $source->globals->slave_status_path
+	);
+}
+
 # Sort requests into those to be performed locally
 # and remotely. Returns two arrayrefs (\@local_labels,\@remote_labels)
 # Our algorithm is very simple. It is a remote request if the "remote renderer"
@@ -927,6 +947,8 @@ sub sort_local_remote {
     unless ($use_renderfarm) {
 	return (\@uncached,[]);
     }
+    
+    my $slave_status = $self->slave_status;
 
     my $url;
     my %is_remote = map { $_ => ( 
@@ -935,9 +957,10 @@ sub sort_local_remote {
 			      !/^(ftp|http|das):/ &&
 			      !$source->is_usertrack($_) &&
 			      !$source->is_remotetrack($_) &&
-			      (($url = $source->remote_renderer||0) &&
+			      (($url = $source->remote_renderer($_)||0) &&
 			      ($url ne 'none') &&
-			      ($url ne 'local')))
+			      ($url ne 'local') &&
+			      $slave_status->select(shellwords($url))))
                         } @uncached;
 
     my @remote    = grep {$is_remote{$_} } @uncached;
@@ -2073,13 +2096,12 @@ sub create_panel_args {
 	      -postgrid     => $postgrid,
 	      -background   => $args->{background} || '',
 	      -truecolor    => $source->global_setting('truecolor') || 0,
-	      -map_fonts_to_truetype    => $source->global_setting('truetype') || 0,
+              -truetype     => $source->global_setting('truetype') || 0,
 	      -extend_grid  => 1,
               -gridcolor    => $source->global_setting('grid color') || 'lightcyan',
               -gridmajorcolor    => $source->global_setting('grid major color') || 'cyan',
 	      @pass_thru_args,   # position is important here to allow user to override settings
 	     );
-
   push @argv, -flip => 1 if $flip;
   my $p  = $self->image_padding;
   my $pl = $source->global_setting('pad_left');
@@ -2582,6 +2604,7 @@ sub balloon_tip_setting {
   } else {
     $val = $source->link_pattern($value,$feature,$panel);
   }
+  $val ||= '';
 
   if ($val=~ /^\s*\[([\w\s]+)\]\s+(.+)/s) {
     $balloon_type = $1;
