@@ -155,8 +155,7 @@ sub lock {
 	      CGI::url(-path=>1),' ',
 	      CGI::query_string());
     } else {
-	my $action = CGI::param('action');
-	warn '[',$self->time,'] ',"[$$] ...$type lock obtained after $elapsed (action=$action)" if DEBUG_LOCK;
+	warn '[',$self->time,'] ',"[$$] ...$type lock obtained after $elapsed (action=",CGI::param('action'),')' if DEBUG_LOCK;
     }
     $self->locktime($self->time());
     return $self->{session} ||= $self->load_session();
@@ -227,8 +226,7 @@ sub unlock {
 	my $result = $lock->do("SELECT RELEASE_LOCK('$lock_name')");
     }
     $self->lockobj(undef);
-    my $action = CGI::param('action');
-    warn "[$$] lock released after ",sprintf("%2.1f",$self->time() - $self->locktime)," s (action=$action)" if DEBUG;
+    warn "[$$] lock released after ",sprintf("%2.1f",$self->time() - $self->locktime)," s (action=",CGI::param('action'),')' if DEBUG;
 }
 
 sub lockfile {
