@@ -30,6 +30,8 @@ END
 
    SHOWING_FROM_TO => '%s from %s:%s..%s',
 
+   CURRENTLY_SHOWING => '(Currently showing %s)',
+
    INSTRUCTIONS      => 'Instructions',
 
    HIDE              => 'Hide',
@@ -98,12 +100,18 @@ END
 # FAVORITE MENU LINKS
    FAVORITES => 'Show Favorites Only',		
     
-   SHOWALL   => 'Show All',
+   SHOWALL   => 'Show Favorites and Others',
+
+   SHOW_ACTIVE => 'Show Active Tracks Only',
+
+   SHOW_ACTIVE_INACTIVE => 'Show Active & Inactive Tracks',
 
    REFRESH_FAV   => 'Refresh Favorites',
     
    CLEAR_FAV     => 'Clear All Favorites',
 
+   SHOW_ACTIVE_TRACKS     => 'Show Active Tracks Only',
+
    ADDED_TO     => 'Add track to favorites',
 
 #############
@@ -160,6 +168,8 @@ END
 
    SELECT_SUBTRACKS   => 'showing %d/%d subtracks',
 
+   TRACK_ID   => 'Track ID=<i>%s</i>',
+
    EDIT       => 'Edit File...',
 
    DELETE     => 'Delete File',
@@ -415,7 +425,7 @@ END
 
  HEIGHT           => 'Height',
 
- PACKING          => 'Packing',
+ PACKING          => 'Spacing',
 
  GLYPH            => 'Shape',
 
@@ -482,6 +492,8 @@ END
 
  CONFIGURE_THIS_TRACK   => '<b>Configure this track</b>',
 
+ POP_OUT               => '<b>Pop out/in</b>',
+
  DOWNLOAD_THIS_TRACK   => '<b>Download this track</b>',
 
  ABOUT_THIS_TRACK   => '<b>About this track</b>',
@@ -490,6 +502,10 @@ END
 
  SHOWING_SUBTRACKS  => '(<i>Showing %d of %d subtracks</i>)',
 
+ OVERLAP            => 'Semi-transparent overlap',
+
+ AUTO_COLORS        => 'Set colors automatically',
+
  SHARE_THIS_TRACK   => '<b>Share this track</b>',
 
  SHARE_ALL          => 'Share these tracks',
